@@ -60,49 +60,71 @@ lsm_c_contig_mn <- function(landscape, directions) UseMethod("lsm_c_contig_mn")
 #' @name lsm_c_contig_mn
 #' @export
 lsm_c_contig_mn.RasterLayer <- function(landscape, directions = 8) {
-    purrr::map_dfr(raster::as.list(landscape),
-                   lsm_c_contig_mn_calc,
-                   directions = directions,
-                   .id = "layer") %>%
-        dplyr::mutate(layer = as.integer(layer))
+
+    result <- lapply(X = raster::as.list(landscape),
+                     FUN = lsm_c_contig_mn_calc,
+                     directions = directions)
+
+    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
+                  layer = as.integer(layer))
 }
 
 #' @name lsm_c_contig_mn
 #' @export
 lsm_c_contig_mn.RasterStack <- function(landscape, directions = 8) {
-    purrr::map_dfr(raster::as.list(landscape),
-                   lsm_c_contig_mn_calc,
-                   directions = directions,
-                   .id = "layer") %>%
-        dplyr::mutate(layer = as.integer(layer))
+
+    result <- lapply(X = raster::as.list(landscape),
+                     FUN = lsm_c_contig_mn_calc,
+                     directions = directions)
+
+    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
+                  layer = as.integer(layer))
 }
 
 #' @name lsm_c_contig_mn
 #' @export
 lsm_c_contig_mn.RasterBrick <- function(landscape, directions = 8) {
-    purrr::map_dfr(raster::as.list(landscape),
-                   lsm_c_contig_mn_calc,
-                   directions = directions,
-                   .id = "layer") %>%
-        dplyr::mutate(layer = as.integer(layer))
+
+    result <- lapply(X = raster::as.list(landscape),
+                     FUN = lsm_c_contig_mn_calc,
+                     directions = directions)
+
+    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
+                  layer = as.integer(layer))
+}
+
+#' @name lsm_c_contig_mn
+#' @export
+lsm_c_contig_mn.stars <- function(landscape, directions = 8) {
+
+    landscape <- methods::as(landscape, "Raster")
+
+    result <- lapply(X = raster::as.list(landscape),
+                     FUN = lsm_c_contig_mn_calc,
+                     directions = directions)
+
+    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
+                  layer = as.integer(layer))
 }
 
 #' @name lsm_c_contig_mn
 #' @export
 lsm_c_contig_mn.list <- function(landscape, directions = 8) {
-    purrr::map_dfr(landscape,
-                   lsm_c_contig_mn_calc,
-                   directions = directions,
-                   .id = "layer") %>%
-        dplyr::mutate(layer = as.integer(layer))
+
+    result <- lapply(X = landscape,
+                     FUN = lsm_c_contig_mn_calc,
+                     directions = directions)
+
+    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
+                  layer = as.integer(layer))
 }
 
 lsm_c_contig_mn_calc <- function(landscape, directions) {
 
-    contig_mn  <- landscape %>%
-        lsm_p_contig_calc(directions = directions) %>%
-        dplyr::group_by(class)  %>%
-        dplyr::summarize(value = mean(value))
+    contig <- lsm_p_contig_calc(landscape, directions = directions)
+
+    contig_mn <- dplyr::summarize(dplyr::group_by(contig, class),
+                                  value = mean(value))
 
     tibble::tibble(
         level = "class",
@@ -111,5 +133,4 @@ lsm_c_contig_mn_calc <- function(landscape, directions) {
         metric = "contig_mn",
         value = as.double(contig_mn$value)
     )
-
 }
