@@ -121,11 +121,13 @@ lsm_c_enn_mn.list <- function(landscape, directions = 8, verbose = TRUE) {
 }
 
 
-lsm_c_enn_mn_calc <- function(landscape, directions, verbose) {
+lsm_c_enn_mn_calc <- function(landscape, directions, verbose,
+                              points = NULL) {
 
     enn <- lsm_p_enn_calc(landscape,
                           directions = directions,
-                          verbose = verbose)
+                          verbose = verbose,
+                          points = points)
 
     enn_mn <-  dplyr::summarize(dplyr::group_by(enn, class),
                                 value = mean(value))
