@@ -113,9 +113,12 @@ lsm_c_gyrate_mn.list <- function(landscape, directions = 8) {
                   layer = as.integer(layer))
 }
 
-lsm_c_gyrate_mn_calc <- function(landscape, directions) {
+lsm_c_gyrate_mn_calc <- function(landscape, directions,
+                                 points = NULL) {
 
-    gyrate <- lsm_p_gyrate_calc(landscape, directions = directions)
+    gyrate <- lsm_p_gyrate_calc(landscape,
+                                directions = directions,
+                                points = points)
 
     gyrate_mn <- dplyr::summarize(dplyr::group_by(gyrate, class),
                                   value = mean(value))
