@@ -96,18 +96,23 @@ lsm_c_pladj.list <- function(landscape) {
 
 lsm_c_pladj_calc <- function(landscape) {
 
-    landscape_padded <- pad_raster(landscape, pad_raster_value = -999,
-                                pad_raster_cells = 1)
+    # convert to matrix
+    if(class(landscape) != "matrix") {
+        landscape <- raster::as.matrix(landscape)
+    }
 
-    tb <- rcpp_get_coocurrence_matrix(raster::as.matrix(landscape_padded),
+    landscape_padded <- pad_raster(landscape, pad_raster_value = -999,
+                                   pad_raster_cells = 1)
+
+    tb <- rcpp_get_coocurrence_matrix(landscape_padded,
                                       directions = as.matrix(4))
 
-    pladj <- sapply(X = seq_len(nrow(tb)), FUN = function(x) {
+    pladj <- vapply(X = seq_len(nrow(tb)), FUN = function(x) {
         like_adjacencies <- tb[x, x]
         total_adjacencies <- sum(tb[x, ])
 
         like_adjacencies / total_adjacencies * 100
-    })
+    }, FUN.VALUE = numeric(1))
 
     pladj <- pladj[-1]
     names <- row.names(tb)[-1]
