@@ -138,12 +138,13 @@ lsm_l_cai_mn.list <- function(landscape,
                   layer = as.integer(layer))
 }
 
-lsm_l_cai_mn_calc <- function(landscape, directions, consider_boundary, edge_depth){
+lsm_l_cai_mn_calc <- function(landscape, directions, consider_boundary, edge_depth, resolution = NULL){
 
-    cai_mean <- dplyr::summarise(lsm_p_cai(landscape,
-                                           directions = directions,
-                                           consider_boundary = consider_boundary,
-                                           edge_depth = edge_depth),
+    cai_mean <- dplyr::summarise(lsm_p_cai_calc(landscape,
+                                                directions = directions,
+                                                consider_boundary = consider_boundary,
+                                                edge_depth = edge_depth,
+                                                resolution = resolution),
                                  value = mean(value))
 
     tibble::tibble(
