@@ -114,9 +114,13 @@ lsm_l_circle_sd.list <- function(landscape, directions = 8) {
                   layer = as.integer(layer))
 }
 
-lsm_l_circle_sd_calc <- function(landscape, directions) {
+lsm_l_circle_sd_calc <- function(landscape, directions,
+                                 resolution = NULL, points = NULL) {
 
-    circle_sd <- dplyr::summarize(lsm_p_circle_calc(landscape, directions = directions),
+    circle_sd <- dplyr::summarize(lsm_p_circle_calc(landscape,
+                                                    directions = directions,
+                                                    resolution = resolution,
+                                                    points = points),
                                   value = stats::sd(value))
 
     tibble::tibble(
