@@ -135,17 +135,27 @@ lsm_l_dcad.list <- function(landscape,
     dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
                   layer = as.integer(layer))
 }
-lsm_l_dcad_calc <- function(landscape, directions, consider_boundary, edge_depth){
+lsm_l_dcad_calc <- function(landscape, directions, consider_boundary, edge_depth,
+                            resolution = NULL, points = NULL){
 
-    area_landscape <- lsm_l_ta_calc(landscape, directions = directions)
+    # get patch area
+    patch_area <- lsm_p_area_calc(landscape,
+                                  directions = directions,
+                                  resolution = resolution)
 
+    # summarise to total area
+    total_area <- dplyr::summarise(patch_area, value = sum(value))
+
+    # get core areas for each patch
     ncore_patch <- lsm_p_ncore_calc(landscape,
                                     directions = directions,
                                     consider_boundary = consider_boundary,
-                                    edge_depth = edge_depth)
+                                    edge_depth = edge_depth,
+                                    points = points)
 
+    # summarise for total landscape
     dcad <- dplyr::mutate(dplyr::summarise(ncore_patch, value = sum(value)),
-                          value = (value / area_landscape$value) * 100)
+                          value = (value / total_area$value) * 100)
 
     tibble::tibble(
         level = "landscape",
