@@ -107,14 +107,20 @@ lsm_l_division.list <- function(landscape, directions = 8) {
                   layer = as.integer(layer))
 }
 
-lsm_l_division_calc <- function(landscape, directions) {
+lsm_l_division_calc <- function(landscape, directions, resolution = NULL) {
 
-    area_landscape <- lsm_l_ta_calc(landscape, directions = directions)
+    # get patch area
+    area_patch <- lsm_p_area_calc(landscape,
+                                  directions = directions,
+                                  resolution = resolution)
 
-    area_patch <- lsm_p_area_calc(landscape, directions = directions)
+    # summarise to total area
+    area_total <- dplyr::summarise(area_patch, value = sum(value))
 
-    division <- dplyr::mutate(area_patch, value = (value / area_landscape$value) ^ 2)
+    # divison for each patch
+    division <- dplyr::mutate(area_patch, value = (value / area_total$value) ^ 2)
 
+    # summarise for whole landscape
     division <- dplyr::mutate(dplyr::summarise(division, value = sum(value)),
                               value = 1 - value)
 
