@@ -9,10 +9,10 @@
 #' @details
 #' \deqn{ED = \frac{E} {A} * 10000}
 #' where \eqn{E} is the total landscape edge in meters and \eqn{A} is the total
-#' landcape area in square meters.
+#' landscape area in square meters.
 #'
 #' ED is an 'Area and Edge metric'. The edge density equals all edges in the landscape
-#' in relation to the landcape area. The boundary of the landscape is only included in the
+#' in relation to the landscape area. The boundary of the landscape is only included in the
 #' corresponding total class edge length if \code{count_boundary = TRUE}.
 #' The metric describes the configuration of the landscape, e.g. because an overall aggregation
 #' of  classes will result in a low edge density. The metric is standardized to the
@@ -119,13 +119,30 @@ lsm_l_ed.list <- function(landscape,
                   layer = as.integer(layer))
 }
 
-lsm_l_ed_calc <- function(landscape, count_boundary, directions) {
+lsm_l_ed_calc <- function(landscape, count_boundary, directions, resolution = NULL) {
 
-    area_landscape <- lsm_l_ta_calc(landscape, directions = directions)
+    # convert to matrix
+    if(class(landscape) != "matrix") {
+        resolution <- raster::res(landscape)
+        landscape <- raster::as.matrix(landscape)
+    }
 
-    edge_landscape <- lsm_l_te_calc(landscape, count_boundary = count_boundary)
+    # get patch area
+    area_patch <- lsm_p_area_calc(landscape,
+                                  directions = directions,
+                                  resolution = resolution)
 
-    ed <- dplyr::mutate(edge_landscape, value = value / area_landscape$value)
+    # summarise to total area
+    area_total <- dplyr::summarise(area_patch, value = sum(value))
+
+    # get total edge
+    edge_landscape <- lsm_l_te_calc(landscape,
+                                    count_boundary = count_boundary,
+                                    resolution = resolution)
+
+    # relative edge density
+    ed <- dplyr::mutate(edge_landscape,
+                        value = value / area_total$value)
 
     tibble::tibble(
         level = "landscape",
