@@ -128,9 +128,14 @@ lsm_l_mutinf.list <- function(landscape,
 
 lsm_l_mutinf_calc <- function(landscape, neighbourhood, ordered, base){
 
-    landscape_matrix <- raster::as.matrix(landscape)
-    cmh  <- rcpp_get_composition_vector(landscape_matrix)
-    coh <- rcpp_get_coocurrence_vector(landscape_matrix,
+    # convert to matrix
+    if(class(landscape) != "matrix") {
+        landscape <- raster::as.matrix(landscape)
+    }
+
+    cmh  <- rcpp_get_composition_vector(landscape)
+
+    coh <- rcpp_get_coocurrence_vector(landscape,
                                        directions = as.matrix(neighbourhood),
                                        ordered = ordered)
 
