@@ -97,10 +97,15 @@ lsm_l_pladj.list <- function(landscape) {
 
 lsm_l_pladj_calc <- function(landscape) {
 
-    landscape_padded <- pad_raster(landscape, pad_raster_value = -999,
+    if(class(landscape) != "matrix") {
+        landscape <- raster::as.matrix(landscape)
+    }
+
+    landscape_padded <- pad_raster(landscape,
+                                   pad_raster_value = -999,
                                    pad_raster_cells = 1)
 
-    tb <- rcpp_get_coocurrence_matrix(raster::as.matrix(landscape_padded),
+    tb <- rcpp_get_coocurrence_matrix(landscape_padded,
                                       directions = as.matrix(4))
 
     like_adjacencies <- sum(diag(tb)[-1])
