@@ -107,16 +107,22 @@ lsm_l_split.list <- function(landscape, directions = 8) {
                   layer = as.integer(layer))
 }
 
-lsm_l_split_calc <- function(landscape, directions) {
+lsm_l_split_calc <- function(landscape, directions, resolution = NULL) {
 
-    area_landscape <- lsm_l_ta_calc(landscape, directions = directions)
+    # get patch area
+    area_patch <- lsm_p_area_calc(landscape,
+                                  directions = directions,
+                                  resolution = resolution)
 
-    area_patch <- lsm_p_area_calc(landscape, directions = directions)
+    # summarise for total landscape
+    area_total <- dplyr::summarise(area_patch, value = sum(value))
 
+    # area squared for each patch
     split <- dplyr::mutate(area_patch, value = value ^ 2)
 
+    # sum of all patches divided by total area
     split <- dplyr::mutate(dplyr::summarise(split, value = sum(value)),
-                           value = (area_landscape$value ^ 2) / value)
+                           value = (area_total$value ^ 2) / value)
 
     tibble::tibble(
         level = "landscape",
