@@ -124,38 +124,61 @@ lsm_p_contig.list <- function(landscape, directions = 8) {
 
 lsm_p_contig_calc <- function(landscape, directions) {
 
-    landscape_labeled <- get_patches(landscape, directions = directions)
+    # convert to matrix
+    if(class(landscape) != "matrix") {
+        landscape <- raster::as.matrix(landscape)
+    }
 
+    # get unique values
+    classes <- get_unique_values(landscape)[[1]]
+
+    # diagonal neighbours
     diagonal_matrix <- matrix(c(1, NA, 1,
                                 NA, 0, NA,
                                 1, NA, 1), 3, 3, byrow = TRUE)
 
+    # x-y neighbours
     straigth_matrix <- matrix(c(NA, 1, NA,
                                 1, 0, 1,
                                 NA, 1, NA), 3, 3, byrow = TRUE)
 
-    contig_patch <- lapply(landscape_labeled, function(patches_class) {
+    contig_patch <- lapply(classes, function(patches_class) {
 
-        n_cells <- table(raster::values(patches_class))
+        # get connected patches
+        patch_mat <- get_patches(landscape,
+                                 directions = directions,
+                                 class = patches_class,
+                                 return_raster = FALSE)[[1]]
+
+        # get number of cells for each patch
+        n_cells <- rcpp_get_composition_vector(patch_mat)
+
+        # get number of patches
         n_patches <- length(n_cells)
 
-        diagonal_neighbours <-
-            rcpp_get_coocurrence_matrix(raster::as.matrix(patches_class),
-                                        directions = as.matrix(diagonal_matrix))
 
-        straigth_neighbours <-
-            rcpp_get_coocurrence_matrix(raster::as.matrix(patches_class),
-                                        directions = as.matrix(straigth_matrix)) * 2
+        # get diagonal neighbours of same patch
+        diagonal_neighbours <- rcpp_get_coocurrence_matrix_diag(patch_mat,
+                                                                directions = as.matrix(diagonal_matrix))
 
-        contiguity <- (((diag(diagonal_neighbours) +
-                             diag(straigth_neighbours) +
+        # get straight neighbours of same patch weighted twice
+        straigth_neighbours <- rcpp_get_coocurrence_matrix_diag(patch_mat,
+                                                                directions = as.matrix(straigth_matrix)) * 2
+
+        # calculated contiguity
+        contiguity <- (((diagonal_neighbours +
+                             straigth_neighbours +
                              n_cells) /
                             n_cells) - 1) / 12
 
-        class <- sub("Class_", "", names(patches_class))
+        class <- patches_class
+
+        rm(patch_mat)
+        gc(verbose = FALSE)
 
         tibble::tibble(class = class,
                        value = contiguity)
+
     })
 
     contig_patch <- dplyr::bind_rows(contig_patch)
