@@ -112,12 +112,25 @@ lsm_p_shape.list <- function(landscape, directions = 8) {
                   layer = as.integer(layer))
 }
 
-lsm_p_shape_calc <- function(landscape, directions){
+lsm_p_shape_calc <- function(landscape, directions, resolution = NULL){
 
-    perimeter_patch <- lsm_p_perim_calc(landscape, directions = directions)
+    # convert to matrix
+    if (class(landscape) != "matrix"){
+        resolution <- raster::res(landscape)
+        landscape <- raster::as.matrix(landscape)
+    }
 
-    area_patch <- lsm_p_area_calc(landscape, directions = directions)
+    # get perimeter of patches
+    perimeter_patch <- lsm_p_perim_calc(landscape,
+                                        directions = directions,
+                                        resolution = resolution)
 
+    # get area of patches
+    area_patch <- lsm_p_area_calc(landscape,
+                                  directions = directions,
+                                  resolution = resolution)
+
+    # calculate shape index
     shape_patch <- dplyr::mutate(area_patch,
                                  value = value * 10000,
                                  n = trunc(sqrt(value)),
