@@ -1,7 +1,4 @@
 library(testthat)
 library(landscapemetrics)
-library(raster)
-library(dplyr)
 
 test_check("landscapemetrics")
-
